@@ -1,7 +1,7 @@
-__version__ = "0.11"
-__version_info__ = ['0', '11']
+__version__ = "0.11.1"
+__version_info__ = ['0', '11', '1']
 __version_vcs_info__ = {'branch': 'master',
- 'revid': '0384d20',
- 'revno': 126,
+ 'revid': '062e70b',
+ 'revno': 127,
  'toplevel': '/home/cstavr/okeanos/devflow'}
 __version_user_info__ = "cstavr@okeanosdev-91.admin.grnet.gr"
